Function average_floor
fn average_floor<T: Average>(x: T, y: T) -> T
Returns the floor value of the average of x and y --
see Average::average_floor.
average_floorfn average_floor<T: Average>(x: T, y: T) -> T
Returns the floor value of the average of x and y --
see Average::average_floor.