Function cbrt
fn cbrt<T: Roots>(x: T) -> T
Returns the truncated principal cube root of an integer -- see Roots::cbrt.
cbrtfn cbrt<T: Roots>(x: T) -> T
Returns the truncated principal cube root of an integer -- see Roots::cbrt.