Function nth_root
fn nth_root<T: Roots>(x: T, n: u32) -> T
Returns the truncated principal nth root of an integer --
see Roots::nth_root.
nth_rootfn nth_root<T: Roots>(x: T, n: u32) -> T
Returns the truncated principal nth root of an integer --
see Roots::nth_root.