Function sqrt
fn sqrt<T: Roots>(x: T) -> T
Returns the truncated principal square root of an integer -- see Roots::sqrt.
sqrtfn sqrt<T: Roots>(x: T) -> T
Returns the truncated principal square root of an integer -- see Roots::sqrt.